@@ -13,11 +13,10 @@ from matplotlib.lines import Line2D
 import pandas as pd
 
 
-
-from CIG import cig_network as cig
-from IT_nil import nil
-from IT_node import IT_node
-from IT import Interval_Tree
+from tempowork.CIG import cig_network as cig
+from tempowork.IT_nil import nil
+from tempowork.IT_node import IT_node
+from tempowork.IT import Interval_Tree
 
 
 
